@@ -264,7 +264,7 @@ sub parallel_check_sizes {
 use constant CANT_FIX => 0;
 sub fix_fid {
     my ($self, $fid) = @_;
-    error(sprintf("Fixing FID %d\n", $fid->id));
+    debug(sprintf("Fixing FID %d\n", $fid->id));
 
     # This should happen first, since the fid gets awkwardly reloaded...
     $fid->update_devcount;
